﻿local L = AceLibrary("AceLocale-2.2"):new("GridStatusRaidDebuff")
local AceOO = AceLibrary("AceOO-2.0")

GridIndicatorDebuffCounter = GridStatus:NewModule("GridIndicatorDebuffCounter")
GridIndicatorDebuffCounter.defaultDB = {
	enabled = true,
	icon = true,	
	counterWidth = 50,	
	counterFontSize = 8,
	counterX = 0,
	counterY = 0,
	counterTest = false,	
}

local indicators = GridFrame.frameClass.prototype.indicators
table.insert(indicators, { type = "debuffCounter",order = 7.1, name = L["Raid Debuff Counter"] })

local statusmap = GridFrame.db.profile.statusmap
if not statusmap["debuffCounter"] then
	statusmap["debuffCounter"] = {["alert_RaidDebuff_Dose"] = true}	
end

local GridIndicatorDebuffCounterFC = AceOO.Class(GridFrame.frameClass)

local _frameClass = nil
if not _frameClass then
	_frameClass = GridFrame.frameClass
	GridFrame.frameClass = GridIndicatorDebuffCounterFC
end

function GridIndicatorDebuffCounter:OnEnable()	
	GridIndicatorDebuffCounter.db.profile.counterTest = false
	GridFrame.options.args["debuffCounter"].hidden = true
	
	self:UpdateOptionMenu()	
end


function GridIndicatorDebuffCounter:UpdateOptionMenu()
	local opt = GridStatus.options.args.alert_RaidDebuff_24.args--GridFrame.options.args.advanced.args
	
	
	opt["Debuff Counter Menu"] = {
		type = "group",
		name = L["Debuff Counter Menu"],
		desc = L["Menu for Debuff Counter"],
		order = 29,
		args = {			
			["counterFontSize"] = {
				type = "range",
				name = L["Font Size"],
				desc = L["Adjust size of font and icon of the Debuff Counter Indicator."],
				order = 1,
				min = 10,
				max = GridFrame.db.profile.frameHeight / 2 or 20,
				step = 1,
				get = function ()
					return GridIndicatorDebuffCounter.db.profile.counterFontSize
				end,
				set = function (v)
					GridIndicatorDebuffCounter.db.profile.counterFontSize = v
					GridFrame:WithAllFrames(function (f) f:SetCounterSize() end)
				end,
				disabled = not (GridIndicatorDebuffCounter.db.profile.enabled and GridIndicatorDebuffCounter.db.profile.counterTest),
			},
			["counterX"] = {
				type = "range",
				name = L["X Offset"],
				desc = L["Adjust the position of the Debuff Counter."],
				order = 2,
				min = 0,
				max = GridFrame.db.profile.frameWidth or 50,
				step = 1,
				get = function ()
					return GridIndicatorDebuffCounter.db.profile.counterX
				end,
				set = function (v)
					GridIndicatorDebuffCounter.db.profile.counterX = v
					GridFrame:WithAllFrames(function (f) f:SetCounterPosition() end)
				end,
				disabled = not (GridIndicatorDebuffCounter.db.profile.enabled and GridIndicatorDebuffCounter.db.profile.counterTest),
			},
			["counterY"] = {
				type = "range",
				name = L["Y Offset"],
				desc = L["Adjust the position of the Debuff Counter."],
				order = 3,
				min = 0,
				max = GridFrame.db.profile.frameHeight or 50,
				step = 1,
				get = function ()
					return GridIndicatorDebuffCounter.db.profile.counterY
				end,
				set = function (v)
					GridIndicatorDebuffCounter.db.profile.counterY = v
					GridFrame:WithAllFrames(function (f) f:SetCounterPosition() end)
				end,
				disabled = not (GridIndicatorDebuffCounter.db.profile.enabled and GridIndicatorDebuffCounter.db.profile.counterTest),
			},
			["counterTest"] = {
				type = "toggle",
				name = L["Show/Hide test debuff"],
				desc = L["Show/Hide the Debuff Counter for positioning"],
				order = 4,
				get = function ()
					return GridIndicatorDebuffCounter.db.profile.counterTest
				end,
				set = function (v)
					GridIndicatorDebuffCounter.db.profile.counterTest = v
					if GridIndicatorDebuffCounter.db.profile.counterTest then
						self.core:SendStatusGained(UnitName("Player"),"alert_RaidDebuff_Dose",99,false,{r = 1.0,g = 0.0,b = 0.0, a = 1 },"Test",7,10,"Interface\\Icons\\INV_Jewelcrafting_ShadowsongAmethyst_02")
					else
						self.core:SendStatusLost(UnitName("Player"), "alert_RaidDebuff_Dose")
					end
					self:UpdateOptionMenu()	
				end,
				disabled = not GridIndicatorDebuffCounter.db.profile.enabled,
			},
			["Show/Hide Debuff Icon"] = {
				type = "toggle",
				name = L["Show/Hide Icon"],
				desc = L["Show/Hide Icon of debuff"],
				order = 5,
				get = function ()
					return GridIndicatorDebuffCounter.db.profile.icon
				end,
				set = function (v)
					GridIndicatorDebuffCounter.db.profile.icon = v					
					self:UpdateOptionMenu()							
				end,
				disabled = not GridIndicatorDebuffCounter.db.profile.enabled,
			},
			["debuffCounterDiabled"] = {
				type = "toggle",
				name = L["Enable"],
				desc = L["Enable Debuff Counter"],
				order = 6,
				get = function ()
					return GridIndicatorDebuffCounter.db.profile.enabled
				end,
				set = function (v)
					GridIndicatorDebuffCounter.db.profile.enabled = v
					if not v and GridIndicatorDebuffCounter.db.profile.counterTest then
						GridIndicatorDebuffCounter.db.profile.counterTest = v
						self.core:SendStatusLost(UnitName("Player"), "alert_RaidDebuff_Dose")
					end	
					self:UpdateOptionMenu()							
				end,
			}			
		}
	}		 
end

function GridIndicatorDebuffCounterFC.prototype:CreateIndicator(indicator)
	GridIndicatorDebuffCounterFC.super.prototype.CreateIndicator(self, indicator)
	local f = self.frame
	if GridIndicatorDebuffCounter.db.profile.enabled and indicator == "debuffCounter" then		
		f.debuffCounter = f.Bar:CreateFontString(nil,"OVERLAY", f)
		f.debuffCounter:SetWidth(GridIndicatorDebuffCounter.db.profile.counterFontSize * 3)
		f.debuffCounter:SetHeight(GridIndicatorDebuffCounter.db.profile.counterFontSize)
		f.debuffCounter:ClearAllPoints() 
		f.debuffCounter:SetPoint("BOTTOMLEFT", f, "BOTTOMLEFT", GridIndicatorDebuffCounter.db.profile.counterX, GridIndicatorDebuffCounter.db.profile.counterY)
		f.debuffCounter:SetFontObject("GameFontNormalSmall")		
		f.debuffCounter:SetTextHeight(GridIndicatorDebuffCounter.db.profile.counterFontSize)		
		f.debuffCounter:SetShadowOffset(0.8, -0.8)	
		f.debuffCounter:SetJustifyH("LEFT")
		f.debuffCounter:SetJustifyV("MIDDLE")
		f.debuffCounter:SetShadowColor(0, 0, 0, 1)
	end
end

function GridIndicatorDebuffCounterFC.prototype:SetIndicator(indicator, color, text, value, maxValue, texture)
	GridIndicatorDebuffCounterFC.super.prototype.SetIndicator(self, indicator, color, text, value, maxValue, texture)	
	if GridIndicatorDebuffCounter.db.profile.enabled and indicator == "debuffCounter"	then
		if not self.frame[indicator] then
			self:CreateIndicator(indicator)
		end
		if value then
			local i = 1
			local icon_space = (GridIndicatorDebuffCounter.db.profile.counterFontSize - 12)
			local rate = value / maxValue
						
			if GridIndicatorDebuffCounter.db.profile.icon then			
				self.frame[indicator]:SetTextColor(2 * rate ,-2 * rate + 2 , 0, 1)
				local	text = "|T"..texture..":0:0:"..(icon_space * 2)..":"..icon_space.."|t" -- debuff icon						
				self.frame[indicator]:SetText(text..value)							
			else
				self.frame[indicator]:SetTextColor(color.r, color.g, color.b, color.a)
				self.frame[indicator]:SetText(value)							
			end
			self.frame[indicator]:Show()			
		else
			self.frame[indicator]:Hide()
		end
	end
end

function GridIndicatorDebuffCounterFC.prototype:ClearIndicator(indicator)
	GridIndicatorDebuffCounterFC.super.prototype.ClearIndicator(self, indicator)
	if indicator == "debuffCounter" then
		if self.frame[indicator] then						
			self.frame[indicator]:Hide()
		end
	end
end

function GridIndicatorDebuffCounterFC.prototype:SetCounterSize()
	GridIndicatorDebuffCounterFC.super.prototype.SetIconSize(self, GridFrame.db.profile.counterSize)
	local f = self.frame
	if f.debuffCounter then		
		f.debuffCounter:SetWidth(GridIndicatorDebuffCounter.db.profile.counterFontSize * 3)
		f.debuffCounter:SetHeight(GridIndicatorDebuffCounter.db.profile.counterFontSize)
		f.debuffCounter:SetTextHeight(GridIndicatorDebuffCounter.db.profile.counterFontSize)
		if GridIndicatorDebuffCounter.db.profile.counterTest then			
			GridIndicatorDebuffCounter.core:SendStatusLost(UnitName("Player"), "alert_RaidDebuff_Dose")
			GridIndicatorDebuffCounter.core:SendStatusGained(UnitName("Player"),"alert_RaidDebuff_Dose",99,false,{r = 1.0,g = 0.0,b = 0.0, a = 1 },"Test",7,10,"Interface\\Icons\\INV_Jewelcrafting_ShadowsongAmethyst_02")			
		end
	end	
end

function GridIndicatorDebuffCounterFC.prototype:SetCounterPosition()	
	local f = self.frame
	if f.debuffCounter then
		f.debuffCounter:ClearAllPoints() 
		f.debuffCounter:SetPoint("BOTTOMLEFT", f, "BOTTOMLEFT", GridIndicatorDebuffCounter.db.profile.counterX, GridIndicatorDebuffCounter.db.profile.counterY)		
	end	
end

